@@ -231,4 +231,26 @@ convertFactorsToStrings <- function(df)
     factors <- sapply(df, is.factor)
     df[factors] <- lapply(df[factors], as.character)
     return(df);
-}
\ No newline at end of file
+}
+
+# JSON encode "rows" post body
+jsonEncodeRowsAndParams <- function(rows, params, na=NULL)
+{
+    nrows <- nrow(rows)
+    p1 <- toJSON(params, auto_unbox=TRUE)
+    cnames <- colnames(rows)
+    p3 <- NULL
+    for(j in 1:nrows)
+    {
+        cvalues <- as.list(rows[j,])
+        names(cvalues) <- cnames
+        if (!is.null(na)) {
+            cvalues[is.na(cvalues)] = na
+        }
+        p2 <- toJSON(cvalues, auto_unbox=TRUE)
+        p3 <- c(p3, p2)
+    }
+    p3 <- paste(p3, collapse=",")
+    pbody <- paste(substr(p1, 1, nchar(p1) - 1),', \"rows\":[',p3,"] }",sep="")
+    return(pbody)
+}
